EpivizFeatureData-class: 'EpivizFeatureData' objects
Description
Encapsulate data for genomic featuresFields
assay:- (integer or character) indicating assay from which data is obtained
Methods
-
.checkColumns(columns): Checks columns are a subset of names(colData(object)).
-
.getColumns(): Returns names(colData(object)).
-
plot(): Calls the scatterPlot method of EpivizDeviceMgr-class with the first measurements in columns as x and y.
-
getMeasurements(): Returns list describing data encapsulated in this object.
Details
The object field is constrained to be SummarizedExperiment. Data is obtained from columns of
a determined assay. Measurement names are checked against the row names of the colData slot. The rowData is assumed
to be a GIntervalTree object, its mcols must contain columns PROBEID and SYMBOL.