tcga_colon_blocks: Example methylation data (blocks) for epivizr vignette.
Description
Example results from methylation analysis of human chromosome 11 using the minfi-package package
of TCGA 450k beadarray samples. This object contains large regions of methylation difference between tumor
and normal samples obtained from blockFinder.
Format
A GRanges object with 129 and mcols:
value- average smooth methylation difference within block
area- block area estimate (abs(value) * length)
cluster- id of cluster blockgroup within which block occurs
indexStart- index of first cluster in block
indexEnd- index of last cluster in block
L- number of clusters in block
clusterL- number of probes in block
p.value- permutation p.value based on difference conditioned on length
fwer- family-wise error rate estimate based on difference conditioned on length
p.valueArea- permutation p.value based on area
fwerArea- family-wise error rate estimate based on area