tcga_colon_curves: Example methylation data (smoothed methylation levels) for epivizr vignette
Description
Example results from methylation analysis of human chromosome 11 using the minfi-package package
of TCGA 450k beadarray samples. This object contains probe cluster level methylation estimates from
blockFinder.
Format
A GRanges object with 7135 ranges and mcols:
id- probe cluster id
type- probe cluster type
blockgroup- probe cluster block group
diff- raw methylation percentage difference between normal and tumor
smooth- smooth methylation percentage difference between normal and tumor
normalMean- mean methylation estimate for normal samples
cancerMean- mean methylation estimate for cancer samples